//---------------------------------------------------------------------------------------------------------- GetJFData.do
// This code creates an extract from raw MDRC's administrative and baseline data.
// 
// This code take as inputs:
// 	1. raw MDRC administrative + baseline data
// 
// This code outputs:
// 	1. A .dta file in the long format data.
// 
// Last Revision: 09/04/2015
//-------------------------------------------------------------------------------------------------------------------------------
args mdrc_ad dtaout_long 







//------------------------------------------------ PART 1  ------------------------------------------------------
// Load up raw MDRC administrative data.
//---------------------------------------------------------------------------------------------------------------
#delimit cr
qui use "`mdrc_ad'", clear
bys pufid: assert _N==1 // unique identifier







//------------------------------------------------ PART 2  ------------------------------------------------------
// Creates variables and saves long format in output.
//---------------------------------------------------------------------------------------------------------------


//--------------------------------------------------------------------------
// Quarter of RA: there are 5 possibilities b/c RA took place from 1/1996 to 2/1997
//--------------------------------------------------------------------------
 rename rarelqtr quarterRA
 label variable quarterRA "Quarter of RA (from 1996q1 to 1997q1)"
 label define quarterRA_lbl 1 "1996Q1" 2 "1996Q2" 3 "1996Q3" 4 "1996Q4" 5 "1997Q1"
 label values quarterRA quarterRA_lbl
//----------------------------------------------------------------------------
// Quarter of RA; which months are included?
// We use AFDC grant and FS grant together with the aggregated variables
// constructed by MDRC to pin down, for all 4803 units but 40, the calendar months
// included in what in the data is called Q0, Q1, etc. 
// The variable that stores this information is monthsinQ0.
//----------------------------------------------------------------------------
do GetJFData_quaterRA



//----------------------------------------------------------------------------
// Setting up variables concerning welfare and FS monthly assistance, for later reshaping.
//
// AFDC monthly variables for amount and whether or or off.
// Lenght of AFDC spell at start of each month.
//
// NOTE: AFDC is a misnomer, it should just say welfare.
//
// Food stamps monthly variables.
// Lenght of FS spell at start of each month.
//----------------------------------------------------------------------------
	//---------------------- Welfare
	qui gen afdconRA = (adcm0>0) // on welfare at RA
	forvalues m=65(-1)0 { // post RA months
		local mm = `m'+ 24
		qui gen afdcamt`mm' = adcm`m'
		qui gen afdcon`mm' = (afdcamt`mm'>0)
	}
	forvalues m=24(-1)1 { // pre RA months
		local mm = -`m'+24
		rename adcpm`m' afdcamt`mm'
		qui gen afdcon`mm' = (afdcamt`mm'>0)
	}
	qui gen afdcon_nmupto0 = 0
	forvalues m=1(1)89 { // all months
		local mm = `m'-1
		qui gen afdcon_nmupto`m' = afdcon_nmupto`mm' + 1 if afdcon`mm'==1 
		qui replace afdcon_nmupto`m' = 0 if afdcon`mm'==0
	}
	//------------------------- FS
	qui gen fsonRA = (fstm0>0) // on FS at RA
	forvalues m=65(-1)0 { // post RA months
		local mm = `m'+ 24
		rename fstm`m' fsamt`mm' // FS transfer in month
		qui gen fson`mm' = (fsamt`mm'>0) // on FS assistance in month
	}
	forvalues m=24(-1)1 { // pre RA months
		local mm = -`m'+24
		rename fstpm`m' fsamt`mm'
		qui gen fson`mm' = (fsamt`mm'>0)
	}
	qui gen fson_nmupto0 = 0
	forvalues m=1(1)89 { // all months
		local mm = `m'-1
		qui gen fson_nmupto`m' = fson_nmupto`mm' + 1 if fson`mm'==1 
		qui replace fson_nmupto`m' = 0 if fson`mm'==0
	}









//----------------------------------------------------------------------------
// Quarterly earnings and employment
//----------------------------------------------------------------------------
	//---------------------------------------
	// we assert that earning information is always available for every 
	// unit of the 4,803 in the sample for the pre-RA period.
	//---------------------------------------
	forvalues q=1(1)8 { // earning in the 8 quarters prior to RA
		assert ernpq`q'~=.
	}
	//---------------------------------------
	// we assert that earning information is always available for every 
	// unit of the 4,803 in the sample for the post-RA quarters 1 through 7.
	//---------------------------------------
	forvalues q=1(1)7 { // earning in the 8 quarters prior to RA
		assert ernq`q'~=.
	}	

	//---------------------------------------
	// We aggregate also the quarters in the two years prior to RA
	//---------------------------------------	
	qui gen ernpq8t5 = ernpq8+ernpq7+ernpq6+ernpq5  // year prior prior to RA: prior qs 8,7,6,5
	qui gen ernpq4t1 = ernpq4+ernpq3+ernpq2+ernpq1 // year prior to RA: prior qs 4,3,2,1
	
	//-----------------------------------------
	// Checking the built-in quarterly indicator of employment: ok, as expected
	// they are constructed based on quarterly earnings
	//-----------------------------------------
	forvalues q=1(1)8 { 
		qui replace emppq`q' = 1 if emppq`q'==100 // not clear why they used 100 to indicate positive earnings
		assert emppq`q'==1 if ernpq`q'>0&ernpq`q'~=.
		assert emppq`q'==0 if ernpq`q'==0&ernpq`q'~=.
		assert emppq`q'==. if ernpq`q'==.
	}
	forvalues q=0(1)21 { 
		qui replace empq`q' = 1 if empq`q'==100 // not clear why they used 100 to indicate positive earnings
		assert empq`q'==1 if ernq`q'>0&ernq`q'~=.
		assert empq`q'==0 if ernq`q'==0&ernq`q'~=.
		assert empq`q'==. if ernq`q'==.
	}
	//--------------------------------------------
	// Variables for reshape
	//--------------------------------------------
	forvalues q=21(-1)0 {
		local qq = `q'+ 8 
		qui gen earn`qq' = ernq`q'
	}
	forvalues q=8(-1)1 {
		local qq = -`q'+8
		qui gen  earn`qq' = ernpq`q'
	}

	forvalues q=29(-1)0 { 
		local m = `q'*3
		rename earn`q' earnm`m'
	}
	//-------------------------
	forvalues q=21(-1)0 {
		local qq = `q'+ 8 
		rename empq`q' empq`qq'
	}
	forvalues q=8(-1)1 {
		local qq = -`q'+8
		qui gen  empq`qq' = emppq`q'
	}
	forvalues q=29(-1)0 { 
		local m = `q'*3
		rename empq`q' empm`m'
	}

	
	
	
	

//-------------------------------------------------------------------
// Reproduce the variables used in DGH_AER paper and code.
// The lines of code themselves are copied and pasted from their code bgh-wmim-table-3.do
//-------------------------------------------------------------------
gen id = _n
label variable id "Unique person identifier"

*Making labels for MDRC age var
label define agecat_lbl 1 "<20" 2 "20-24" 3 "25-34" 4 "35-44" 5 ">=45"
label values agecat agecat_lbl

cap label drop ages
label define ages 1 "Younger than 20"
label define ages 2 "20 - 24", add
label define ages 3 "25 - 34", add
label define ages 4 "35 - 44", add
label define ages 5 "45 or older", add
label values agecat ages

*Making our age vars
cap gen agelt25 = agecat< 3
cap gen age2534 = agecat==3
cap gen agegt34 = agecat> 3
*Making our number-of-kids-more-than-2 var
cap gen kidctgt2 = kidcount>2 if kidcount<.
*Making vars summing outcomes for pre-RA quarters 1-7 and 8-16. NOTE: these are quarterly avgs
for any adcpq fstpq : cap gen Xa17  = (X1 + X2 + X3 + X4 + X5 + X6 + X7)/7
for any ernpq       : cap gen Xa18  = (X1 + X2 + X3 + X4 + X5 + X6 + X7 + X8)/8
*Making any* vars for pre-RA period
for X in any adcpq fstpq : for Y in num 1/7 : cap gen anyXY  = XY>0 if XY<.
for X in any ernpq       : for Y in num 1/8 : cap gen anyXY  = XY>0 if XY<.
*Making fraction-of-pretreatment-quarters-with vars
for X in any adcpq fstpq : cap egen anyXa17  = rmean(anyX1-anyX7)
for X in any ernpq       : cap egen anyXa18  = rmean(anyX1-anyX8)
*Making HS Grad dummy
cap gen hsgrad = hsged==1 & college==0 & tecdip==0
*Making more-than-HS Grad dummy
cap gen mthsgrad = (college==1) | (tecdip==1) if college<. & tecdip<.
label variable mthsgrad "More education than HS diploma"
*Making dummy for having had any AFDC income in year before RA
cap gen prevafdc = adcpq1 + adcpq2 + adcpq3 + adcpq4
replace prevafdc = prevafdc>0 if prevafdc<.
label variable prevafdc "1(any afdc income in yr before RA)"
*Check for missing values, dummy them out, replace missing values with 0, and then add vars to pscorevars global
gen misshs = (college==. | tecdip==. | hsd==. | ged==.)
for var nohsged  hsged : replace X=0 if misshs==1

gen misskidctgt2 = (kidctgt2==.)
replace kidctgt2=0 if kidctgt2==.


gen missmar = (marital==.)
for var marnvr marapt : replace X=0 if X==.

*Run pscore logit, predict propensity score (pscore), and generate IPW (pscorewt)
logit e $pscorevars
predict double pscore                                      
gen double pscorewt = e/pscore + (1-e)/(1-pscore)
drop pscore
*Making transfers var (sum of cash assistance and food stamps)
for Y in num 1/16 : gen transqY  = adcqY + fstqY
*Making vars summing outcomes for quarters 1-7 and 8-16. NOTE: these are quarterly avgs
for any totq ernq adcq fstq transq : gen Xa17  = (X1 + X2 + X3 + X4 + X5 + X6 + X7)/7
for any totq ernq adcq fstq transq : gen Xa816 = (X8 + X9 + X10 + X11 + X12 + X13 + X14 + X15 + X16)/9
for any totq ernq adcq fstq transq : cap drop Xa116
for any totq ernq adcq fstq transq : gen Xa116 = (X1 + X2 + X3 + X4 + X5 + X6 + X7 + X8 + X9 + X10 + X11 + X12 + X13 + X14 + X15 + X16)/16
*Making any* vars
for X in any totq ernq adcq fstq transq : for Y in num 1/16 : gen anyXY  = XY>0 if XY<.
for X in any totq ernq transq : egen anyXa17 =  rmean(anyX1-anyX7)
*there are missing values for 30 obs in Q16
for X in any totq ernq transq : egen anyXa816 = rmean(anyX8-anyX16)
for X in any totq ernq transq : egen anyXa116 = rmean(anyX1-anyX16)
*there are missing values for 30 obs in Q16
for X in any totq ernq transq : replace anyXa816 = . if anyX16==.
for X in any totq ernq transq : replace anyXa116 = . if anyX16==.








//------------------------------------------------------------------- 
// Keep only variables used later on, to lighten the data set
//-------------------------------------------------------------------
keep id pufid e  quarterRA monthsinQ0 ///
	 yngchtru kidcount  marnvr  marapt  ///
	 black hisp white  ///
	 hsged  nohsged mthsgrad ///
	 yremp  applcant prevafdc agelt25 age2534 agegt34 kidctgt2 misskidctgt2 misshs missmar pscorewt ///
	 afdcamt* afdcon* adcpq*  fstpq*   ///
	 ernq* ernpq*  ///
	 anyernpq* anyadcpq* anyfstpq* anyadcq* anyernqa* 

drop *916
drop *816
drop *116






 
 
//----------------------------------------------------------------------------
// Go to long (monthly) format
//----------------------------------------------------------------------------
qui reshape long afdcamt@ afdcon@, i(pufid) j(month)


qui replace month = month-8*3
qui gen quarter = floor(month/3) if monthsinQ0==3
qui replace quarter = floor((month+1)/3) if monthsinQ0==2
qui replace quarter = floor((month+2)/3) if monthsinQ0==1

label variable afdcon "On/Off Welfare (monthly)"
label define afdcon_lbl 0 "off Welfare" 1 "on Welfare"
label values afdcon afdcon_lbl



qui gen one = (afdcon==1)
qui bys id quarter: egen afdconq = max(one)
drop one
forvalues q=1(1)16 {
	qui gen one = afdconq if quarter==`q'
	qui bys id: egen afdconq`q' = max(one)
	drop one
	label variable afdconq`q' "On/Off Welfare any month of quarter"
	label values afdconq`q' afdcon_lbl
}


sort pufid quarter month
qui by pufid quarter: egen afdcon_nminq = sum(afdcon)
label variable afdcon_nminq 	"On/Off Welfare n. month in quarter"
label define afdcon_nminq_lbl 0 "Always Off Welfare" 1 "1 month on" 2 "2 months on" 3 "Always on Welfare"
label values afdcon_nminq afdcon_nminq_lbl


qui gen earnq = .
forvalues q=8(-1)1 {
qui replace earnq = ernpq`q' if quarter==-`q'
}
forvalues q=0(1)21 {
qui replace earnq = ernq`q' if quarter==`q'
}





//--------------------------------------------------------------------------
// We can back out the exact dates of RA, we know all RA took place b/w 1/1996 and 2/1997
// and we know in which quater RA took place (now in the variable quarterRA)
// We us this information to attach a calendar year and a calendar month
//------------------------------------------------------------------------------
qui gen month_withinq = .
sort pufid quarter month
qui by pufid quarter: replace month_withinq = _n

qui gen date = .
qui replace date = date("1-1996","MY") if quarterRA==1&month_withinq==1&quarter==0 // 1996Q1, jan
qui replace date = date("2-1996","MY") if quarterRA==1&month_withinq==2&quarter==0 // 1996Q1, feb
qui replace date = date("3-1996","MY") if quarterRA==1&month_withinq==3&quarter==0 // 1996Q1, march

qui replace date = date("4-1996","MY") if quarterRA==2&month_withinq==1 &quarter==0 // 1996Q2, april
qui replace date = date("5-1996","MY") if quarterRA==2&month_withinq==2&quarter==0 // 1996Q2, may
qui replace date = date("6-1996","MY") if quarterRA==2&month_withinq==3&quarter==0 // 1996Q2, june

qui replace date = date("7-1996","MY") if quarterRA==3&month_withinq==1 &quarter==0 // 1996Q4, july
qui replace date = date("8-1996","MY") if quarterRA==3&month_withinq==2&quarter==0 // 1996Q4, aug
qui replace date = date("9-1996","MY") if quarterRA==3&month_withinq==3&quarter==0 // 1996Q4, sept

qui replace date = date("10-1996","MY") if quarterRA==4&month_withinq==1&quarter==0 // 1996Q4, oct
qui replace date = date("11-1996","MY") if quarterRA==4&month_withinq==2&quarter==0 // 1996Q4, nov
qui replace date = date("12-1996","MY") if quarterRA==4&month_withinq==3&quarter==0 // 1996Q4, dec

qui replace date = date("1-1997","MY") if quarterRA==5&month_withinq==1 &quarter==0 // 1997Q1, jan
qui replace date = date("2-1997","MY") if quarterRA==5&month_withinq==2 &quarter==0 // 1997Q1, feb
qui replace date = date("3-1997","MY") if quarterRA==5&month_withinq==3 &quarter==0 // 1997Q1, march
format date %td

qui gen year = year(date)
qui gen monthc = month(date)
drop date

qui gen date = ym(year,month)
format date %tm

// now we simply fill backward and forward
qui gen year_lead = .
qui gen monthc_lead = .
qui gen one = (year==.&monthc==.)

forvalues r=1(1)24 {
	sort pufid month
	qui by  pufid : replace year_lead = year[_n+1]
	qui by  pufid : replace monthc_lead = monthc[_n+1]
	qui replace year = year_lead if monthc_lead>1&monthc_lead~=.&one==1
	qui replace monthc = monthc_lead-1 if monthc_lead>1&monthc_lead~=.&one==1
	qui replace year = year_lead -1 if monthc_lead==1&monthc_lead~=.&one==1
	qui replace monthc = 12 if monthc_lead==1&monthc_lead~=.&one==1
	qui replace one = 0 if year~=.
}

qui gen year_lag = .
qui gen monthc_lag = .

forvalues r=1(1)65 {
	sort pufid month
	qui by  pufid : replace year_lag = year[_n-1]
	qui by  pufid : replace monthc_lag = monthc[_n-1]
	qui replace year = year_lag if monthc_lag<12&monthc_lag~=.&one==1
	qui replace monthc = monthc_lag+1 if monthc_lag<12&monthc_lag~=.&one==1
	qui replace year = year_lag +1 if monthc_lag==12&monthc_lag~=.&one==1
	qui replace monthc = 1 if monthc_lag==12&monthc_lag~=.&one==1
	qui replace one = 0 if year~=.
}

drop month_withinq
drop one
drop *_lead
drop *_lag
assert year~=.
assert monthc~=.


//-------------------------------------------------------------------------------------
// Clearn up and save the long format of the data
//-------------------------------------------------------------------------------------
drop monthsinQ0 
drop afdconq8-afdconq16
drop ernq8-ernq21
drop if quarter>7 	// not used
drop if quarter<-1 // not used


qui compress _all
sort pufid quarter month
qui save "`dtaout_long'", replace











